@@ -1,4 +1,5 @@
-__version__ = '0.2.6'
+__version__ = '0.2.7'
+
 import json
 import os
 import termcolor
@@ -6,7 +7,6 @@ from os import path
 from termcolor import colored
 
 
-
 class DB:
   """
   Creates a new instance of a database.
@@ -145,6 +145,7 @@ class DB:
           varType = type(data)
           return print(colored(f'Error: expected type - \'int\' or \'float\', got {varType}.', 'red'))
 	
+  
   def unlink(self):
     """
     Unlinks a database, and deletes all associated data
@@ -153,6 +154,16 @@ class DB:
     if path.exists(f'DB/{self.name}.json'):
       os.remove(f'DB/{self.name}.json')
 
+  def exists(key):
+    """
+    Checks if a key exists in the database.
+    """
+
+    for x in range(len(arr)):
+      if arr[x]['key'] == key:
+        return True;
+    
+    return False;
 
   def add(self, key, data):
     """
